@@ -184,8 +184,8 @@ binomial.CARadaptive <- function(formula, data = NULL, trials, W, burnin, n.samp
   tau_phi_shape <- (n.sites*n.time/2) + prior.tau2[1]
   # general MCMC housekeeping
   n.save        <- ifelse(thin == 1, (n.sample - burnin), (n.sample - burnin) / thin)
-  accept.all    <- rep(0, 8)
-  accept        <- accept.all
+  accept    <- rep(0, 8)
+
   # storage of parameters in the MCMC, 
   samples.beta  <- array(NA, c(n.save, p))
   samples.phi   <- array(NA, c(n.save, n.sites * n.time))
@@ -403,7 +403,7 @@ binomial.CARadaptive <- function(formula, data = NULL, trials, W, burnin, n.samp
     }
     
     # adjust the acceptance rate if required
-    if(j %% 100 == 0){
+    if(j %% 100 == 0 & j < burnin){
         accept.beta <- 100 * accept[1] / accept[2]
         accept.phi <- 100 * accept[3] / accept[4]
         accept.w <- 100 * accept[7] / accept[8]
@@ -458,7 +458,6 @@ binomial.CARadaptive <- function(formula, data = NULL, trials, W, burnin, n.samp
         }else
         {
         }  
-        accept.all         <- accept.all + accept
         accept             <- accept*0
     }else
     {}
@@ -476,10 +475,10 @@ binomial.CARadaptive <- function(formula, data = NULL, trials, W, burnin, n.samp
 #### Summarise and save the results 
 ###################################
 ## Compute the acceptance rates
-accept.beta  <- 100 * accept.all[1] / accept.all[2]
-accept.phi   <- 100 * accept.all[3] / accept.all[4]
-accept.rho <- 100 * accept.all[5] / accept.all[6]
-accept.w     <- 100 * accept.all[7] / accept.all[8]
+accept.beta  <- 100 * accept[1] / accept[2]
+accept.phi   <- 100 * accept[3] / accept[4]
+accept.rho <- 100 * accept[5] / accept[6]
+accept.w     <- 100 * accept[7] / accept[8]
 accept.alpha <- 100
 
   if(!is.null(rhofix))
