@@ -181,8 +181,7 @@ samples.loglike <- array(NA, c(n.keep, N.all))
     
     
 #### Specify the Metropolis quantities
-accept.all <- rep(0,12)
-accept <- accept.all
+accept <- rep(0,12)
 proposal.sd.beta <- 0.01
 proposal.sd.phi <- 0.1
 proposal.sd.delta <- 0.1
@@ -516,8 +515,7 @@ n.islands <- max(W.islands$nc)
     ########################################
     ## Self tune the acceptance probabilties
     ########################################
-    k <- j/100
-        if(ceiling(k)==floor(k))
+        if(ceiling(j/100)==floor(j/100) & j < burnin)
         {
         #### Update the proposal sds
             if(p>2)
@@ -532,7 +530,6 @@ n.islands <- max(W.islands$nc)
             if(interaction) proposal.sd.gamma <- common.accceptrates1(accept[7:8], proposal.sd.gamma, 40, 50)
             if(!fix.rho.S) proposal.sd.rho <- common.accceptrates2(accept[9:10], proposal.sd.rho, 40, 50, 0.5)
             if(!fix.rho.T) proposal.sd.lambda <- common.accceptrates2(accept[11:12], proposal.sd.lambda, 40, 50, 0.5)
-        accept.all <- accept.all + accept
         accept <- rep(0,12)
         }else
         {}
@@ -563,12 +560,12 @@ n.islands <- max(W.islands$nc)
 #### Summarise and save the results 
 ###################################
 ## Compute the acceptance rates
-accept.beta <- 100 * accept.all[1] / accept.all[2]
-accept.phi <- 100 * accept.all[3] / accept.all[4]
-accept.delta <- 100 * accept.all[5] / accept.all[6]
+accept.beta <- 100 * accept[1] / accept[2]
+accept.phi <- 100 * accept[3] / accept[4]
+accept.delta <- 100 * accept[5] / accept[6]
     if(!fix.rho.S)
     {
-    accept.rho <- 100 * accept.all[9] / accept.all[10]
+    accept.rho <- 100 * accept[9] / accept[10]
     }else
     {
     accept.rho <- NA    
@@ -576,7 +573,7 @@ accept.delta <- 100 * accept.all[5] / accept.all[6]
 
     if(!fix.rho.T)
     {
-    accept.lambda <- 100 * accept.all[11] / accept.all[12]
+    accept.lambda <- 100 * accept[11] / accept[12]
     }else
     {
     accept.lambda <- NA    
@@ -584,7 +581,7 @@ accept.delta <- 100 * accept.all[5] / accept.all[6]
 
     if(interaction)
     {
-    accept.gamma <- 100 * accept.all[7] / accept.all[8]
+    accept.gamma <- 100 * accept[7] / accept[8]
     accept.final <- c(accept.beta, accept.phi, accept.delta, accept.gamma, accept.rho, accept.lambda)
     names(accept.final) <- c("beta", "phi", "delta", "gamma", "rho.S", "rho.T")
     }else
