@@ -695,8 +695,7 @@ binomial.CARclustrends <- function(formula, data=NULL, trials, W, burnin, n.samp
     #------------------------------------------------------------------------------------------------------------------------------------------------------
     # Self tune the acceptance probabilties
     #------------------------------------------------------------------------------------------------------------------------------------------------------
-    k <- j/100
-    if(ceiling(k)==floor(k))
+    if(ceiling(j/100)==floor(j/100) & j < burnin)
     {
       #------------------------------------------------------------------------------------------------------------------------------------------------------
       # Determine the acceptance probabilities
