@@ -164,16 +164,15 @@ samples.loglike <- array(NA, c(n.keep, N.all))
     if(!is.null(X))
     {
     samples.beta <- array(NA, c(n.keep, p))
-    accept.all <- rep(0,8)
+    accept <- rep(0,8)
     proposal.corr.beta <- solve(t(X.standardised) %*% X.standardised)
     chol.proposal.corr.beta <- chol(proposal.corr.beta) 
     proposal.sd.beta <- 0.01
     }else
     {
-    accept.all <- rep(0,6)    
+    accept <- rep(0,6)    
     }
 
-accept <- accept.all
 proposal.sd.lambda <- 0.1
 proposal.sd.delta <- 0.1
 proposal.sd.phi <- 0.1
@@ -381,8 +380,7 @@ trials.mat <- matrix(trials, nrow=K, ncol=N, byrow=FALSE)
     ########################################
     ## Self tune the acceptance probabilties
     ########################################
-    k <- j/100
-        if(ceiling(k)==floor(k))
+        if(ceiling(j/100)==floor(j/100) & j < burnin)
         {
             if(!is.null(X))
             {
@@ -396,14 +394,12 @@ trials.mat <- matrix(trials, nrow=K, ncol=N, byrow=FALSE)
             proposal.sd.phi <- common.accceptrates1(accept[5:6], proposal.sd.phi, 40, 50)
             proposal.sd.lambda <- common.accceptrates2(accept[1:2], proposal.sd.lambda, 20, 40, 10)
             proposal.sd.delta <- common.accceptrates2(accept[3:4], proposal.sd.delta, 40, 50, prior.delta/6)
-            accept.all <- accept.all + accept
             accept <- rep(0,8)  
             }else
             {
             proposal.sd.phi <- common.accceptrates1(accept[5:6], proposal.sd.phi, 40, 50)
             proposal.sd.lambda <- common.accceptrates2(accept[1:2], proposal.sd.lambda, 20, 40, 10)
             proposal.sd.delta <- common.accceptrates2(accept[3:4], proposal.sd.delta, 40, 50, prior.delta/6)
-            accept.all <- accept.all + accept
             accept <- rep(0,6)     
             }
         }else
@@ -435,13 +431,13 @@ trials.mat <- matrix(trials, nrow=K, ncol=N, byrow=FALSE)
 #### Summarise and save the results 
 ###################################
 #### Compute the acceptance rates
-accept.lambda <- 100 * accept.all[1] / accept.all[2]
-accept.delta <- 100 * accept.all[3] / accept.all[4]
-accept.phi <- 100 * accept.all[5] / accept.all[6]
+accept.lambda <- 100 * accept[1] / accept[2]
+accept.delta <- 100 * accept[3] / accept[4]
+accept.phi <- 100 * accept[5] / accept[6]
 accept.gamma <- 100
     if(!is.null(X))
     {
-    accept.beta <- 100 * accept.all[7] / accept.all[8]   
+    accept.beta <- 100 * accept[7] / accept[8]   
     accept.final <- c(accept.beta, accept.lambda, accept.delta, accept.phi, accept.gamma)
     names(accept.final) <- c("beta", "lambda", "delta", "phi", "rho.T")   
     }else
