@@ -174,8 +174,7 @@ gaussian.CARadaptive <- function(formula, data = NULL, W, burnin, n.sample, thin
   tau_phi_shape <- (n.sites*n.time/2) + prior.tau2[1]
   # general MCMC housekeeping
   n.save        <- ifelse(thin == 1, (n.sample - burnin), (n.sample - burnin) / thin)
-  accept.all    <- rep(0, 8)
-  accept        <- accept.all
+  accept    <- rep(0, 8)
   # storage of parameters in the MCMC, 
   samples.beta  <- array(NA, c(n.save, p))
   samples.phi   <- array(NA, c(n.save, n.sites * n.time))
@@ -372,7 +371,7 @@ gaussian.CARadaptive <- function(formula, data = NULL, W, burnin, n.sample, thin
     
     
         # adjust the acceptance rate if required
-        if(j %% 100 == 0){
+        if(j %% 100 == 0 & j < burnin){
              accept.w <- 100 * accept[7] / accept[8]
             if(is.null(rhofix))
             {
@@ -403,7 +402,6 @@ gaussian.CARadaptive <- function(formula, data = NULL, W, burnin, n.sample, thin
             }else
             {
             }  
-            accept.all         <- accept.all + accept
             accept             <- accept*0
             
     }
@@ -424,8 +422,8 @@ gaussian.CARadaptive <- function(formula, data = NULL, W, burnin, n.sample, thin
 ## Compute the acceptance rates
 accept.beta  <- 100
 accept.phi   <- 100
-accept.rho <- 100 * accept.all[5] / accept.all[6]
-accept.w     <- 100 * accept.all[7] / accept.all[8]
+accept.rho <- 100 * accept[5] / accept[6]
+accept.w     <- 100 * accept[7] / accept[8]
 accept.alpha <- 100
   if(!is.null(rhofix))
   {
