@@ -133,8 +133,7 @@ samples.loglike <- array(NA, c(n.keep, N.all))
 
 
 #### Specify the Metropolis quantities
-accept.all <- rep(0,6)
-accept <- accept.all
+accept <- rep(0,6)
 proposal.sd.phi <- 0.1
 proposal.sd.rho <- 0.05
 proposal.sd.beta <- 0.01
@@ -242,7 +241,7 @@ n.islands <- max(W.islands$nc)
     phi <- as.numeric(phi.temp)  - mean(as.numeric(phi.temp))
     phi.mat <- matrix(phi, nrow=K, ncol=N, byrow=FALSE)
     accept[3] <- accept[3] + temp1[[2]]
-    accept[4] <- accept[4] + K*N - n.miss    
+    accept[4] <- accept[4] + K*N    
      
     
     
@@ -326,8 +325,7 @@ n.islands <- max(W.islands$nc)
     ########################################
     ## Self tune the acceptance probabilties
     ########################################
-    k <- j/100
-        if(ceiling(k)==floor(k))
+        if(ceiling(j/100)==floor(j/100) & j < burnin)
         {
         #### Update the proposal sds
             if(p>2)
@@ -339,7 +337,6 @@ n.islands <- max(W.islands$nc)
             }
         proposal.sd.phi <- common.accceptrates1(accept[3:4], proposal.sd.phi, 40, 50)
             if(!fix.rho.S) proposal.sd.rho <- common.accceptrates2(accept[5:6], proposal.sd.rho, 40, 50, 0.5) 
-        accept.all <- accept.all + accept
         accept <- rep(0,6)  
         }else
         {}
@@ -370,11 +367,11 @@ n.islands <- max(W.islands$nc)
 #### Summarise and save the results 
 ###################################
 #### Compute the acceptance rates
-accept.beta <- 100 * accept.all[1] / accept.all[2]
-accept.phi <- 100 * accept.all[3] / accept.all[4]
+accept.beta <- 100 * accept[1] / accept[2]
+accept.phi <- 100 * accept[3] / accept[4]
     if(!fix.rho.S)
     {
-    accept.rho <- 100 * accept.all[5] / accept.all[6]
+    accept.rho <- 100 * accept[5] / accept[6]
     }else
     {
     accept.rho <- NA    
