@@ -151,8 +151,7 @@ samples.loglike <- array(NA, c(n.keep, N.all))
 
     
 #### Specify the Metropolis quantities
-accept.all <- rep(0,12)
-accept <- accept.all
+accept <- rep(0,12)
 proposal.sd.beta <- 0.01
 proposal.sd.phi <- 0.1
 proposal.sd.delta <- 0.1
@@ -416,8 +415,7 @@ n.islands <- max(W.islands$nc)
     ########################################
     ## Self tune the acceptance probabilties
     ########################################
-    k <- j/100
-        if(ceiling(k)==floor(k))
+        if(ceiling(j/100)==floor(j/100) & j < burnin)
         {
         #### Update the proposal sds
             if(p>2)
@@ -432,7 +430,6 @@ n.islands <- max(W.islands$nc)
         proposal.sd.delta <- common.accceptrates1(accept[7:8], proposal.sd.delta, 40, 50)
             if(!fix.rho.int) proposal.sd.rho <- common.accceptrates2(accept[9:10], proposal.sd.rho, 40, 50, 0.5)
             if(!fix.rho.slo) proposal.sd.lambda <- common.accceptrates2(accept[11:12], proposal.sd.lambda, 40, 50, 0.5)
-        accept.all <- accept.all + accept
         accept <- rep(0,12)
         }else
         {}
@@ -463,20 +460,20 @@ n.islands <- max(W.islands$nc)
 #### Summarise and save the results 
 ###################################
 ## Compute the acceptance rates
-accept.beta <- 100 * accept.all[1] / accept.all[2]
-accept.alpha <- 100 * accept.all[3] / accept.all[4]
-accept.phi <- 100 * accept.all[5] / accept.all[6]
-accept.delta <- 100 * accept.all[7] / accept.all[8]
+accept.beta <- 100 * accept[1] / accept[2]
+accept.alpha <- 100 * accept[3] / accept[4]
+accept.phi <- 100 * accept[5] / accept[6]
+accept.delta <- 100 * accept[7] / accept[8]
     if(!fix.rho.int)
     {
-    accept.rho <- 100 * accept.all[9] / accept.all[10]
+    accept.rho <- 100 * accept[9] / accept[10]
     }else
     {
     accept.rho <- NA    
     }
     if(!fix.rho.slo)
     {
-    accept.lambda <- 100 * accept.all[11] / accept.all[12]
+    accept.lambda <- 100 * accept[11] / accept[12]
     }else
     {
     accept.lambda <- NA    
