@@ -121,8 +121,7 @@ sig2 <- var(delta)/10
 
   
   #### Specify the Metropolis quantities
-  accept.all <- rep(0,10)
-  accept <- accept.all
+  accept <- rep(0,10)
   proposal.sd.phi <- 0.1
   proposal.sd.rho <- 0.05
   proposal.sd.beta <- 0.01
@@ -377,8 +376,7 @@ sig2 <- var(delta)/10
     ########################################
     ## Self tune the acceptance probabilties
     ########################################
-    k <- j/100
-    if(ceiling(k)==floor(k))
+    if(ceiling(j/100)==floor(j/100) & j < burnin)
     {
       #### Update the proposal sds
       if(p>2)
@@ -392,7 +390,6 @@ sig2 <- var(delta)/10
       proposal.sd.delta <- common.accceptrates1(accept[7:8], proposal.sd.delta, 40, 50)
       if(!fix.rho.S) proposal.sd.rho <- common.accceptrates2(accept[5:6], proposal.sd.rho, 40, 50, 0.5)
       if(!fix.rho.T) proposal.sd.lambda <- common.accceptrates2(accept[9:10], proposal.sd.lambda, 40, 50, 0.5)
-      accept.all <- accept.all + accept
       accept <- rep(0,10)
     }else
     {}
@@ -420,12 +417,12 @@ sig2 <- var(delta)/10
 #### Summarise and save the results 
 ###################################
 ## Compute the acceptance rates
-accept.beta <- 100 * accept.all[1] / accept.all[2]
-accept.phi <- 100 * accept.all[3] / accept.all[4]
-accept.delta <- 100 * accept.all[7] / accept.all[8]
+accept.beta <- 100 * accept[1] / accept[2]
+accept.phi <- 100 * accept[3] / accept[4]
+accept.delta <- 100 * accept[7] / accept[8]
    if(!fix.rho.S)
    {
-   accept.rho <- 100 * accept.all[5] / accept.all[6]
+   accept.rho <- 100 * accept[5] / accept[6]
    }else
    {
    accept.rho <- NA    
@@ -433,7 +430,7 @@ accept.delta <- 100 * accept.all[7] / accept.all[8]
   
    if(!fix.rho.T)
    {
-   accept.lambda <- 100 * accept.all[9] / accept.all[10]
+   accept.lambda <- 100 * accept[9] / accept[10]
    }else
    {
    accept.lambda <- NA    
